<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AllFields</name>
    <message>
        <location filename="../details.cpp" line="627"/>
        <source>Field</source>
        <translation>フィールド</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="627"/>
        <source>Field name</source>
        <translation>フィールド名</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="628"/>
        <source>Description</source>
        <translation>説明</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="628"/>
        <source>Field description</source>
        <translation>フィールドの説明</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="629"/>
        <source>Value</source>
        <translation>値</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="629"/>
        <source>Field value</source>
        <translation>フィールドの値</translation>
    </message>
</context>
<context>
    <name>Boxvar</name>
    <message>
        <location filename="../prefs.cpp" line="59"/>
        <source>Exit on closing</source>
        <translation>[閉じる] で終了する</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="60"/>
        <source>Remember Position</source>
        <translation>位置を記憶する</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="68"/>
        <source>Host Name Lookup</source>
        <translation>ホスト名参照</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="69"/>
        <source>Service Name Lookup</source>
        <translation>サービス名参照</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="75"/>
        <source>Disclosure Triangles</source>
        <translation>展開三角形</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="76"/>
        <source>Branch Lines</source>
        <translation>ブランチライン</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="82"/>
        <source>Auto Save Settings on Exit</source>
        <translation>終了時に自動保存</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="83"/>
        <source>Selection: Copy PIDs to Clipboard</source>
        <translation>選択: PIDをクリップボードにコピー</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="85"/>
        <source>Normalize NICE</source>
        <translation>NICE正規化</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="86"/>
        <source>Use pmap for Map Names</source>
        <translation>マップ名としてpmapを使用</translation>
    </message>
</context>
<context>
    <name>Cbgroup</name>
    <message>
        <location filename="../prefs.cpp" line="106"/>
        <source>General</source>
        <translation>全般</translation>
    </message>
</context>
<context>
    <name>ControlBar</name>
    <message>
        <location filename="../misc.cpp" line="634"/>
        <source>Linear</source>
        <translation>リニア</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="637"/>
        <source>Tree</source>
        <translation>ツリー</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="646"/>
        <source>Thread</source>
        <translation>スレッド</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="653"/>
        <source>All Processes</source>
        <translation>すべてのプロセス</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="654"/>
        <source>Your Processes</source>
        <translation>自分のプロセス</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="655"/>
        <source>Non-Root Processes</source>
        <translation>Root 以外のプロセス</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="656"/>
        <source>Running Processes</source>
        <translation>実行中のプロセス</translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="672"/>
        <source>Pause (Ctrl+Space)</source>
        <translation>一時停止 (Ctrl+Space)</translation>
    </message>
</context>
<context>
    <name>Details</name>
    <message>
        <location filename="../details.cpp" line="36"/>
        <source>Process %1 ( %2 ) - details</source>
        <translation>Process %1 ( %2 ) - 詳細</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="45"/>
        <source>Files</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="54"/>
        <source>Sockets</source>
        <translation>ソケット</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="59"/>
        <source>Memory Maps</source>
        <translation>メモリマップ</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="61"/>
        <source>Environment</source>
        <translation>環境</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="62"/>
        <source>All Fields</source>
        <translation>すべてのフィールド</translation>
    </message>
</context>
<context>
    <name>Environ</name>
    <message>
        <location filename="../details.cpp" line="579"/>
        <source>Variable</source>
        <translation>変数</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="579"/>
        <source>Variable name</source>
        <translation>変数名</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="580"/>
        <source>Value</source>
        <translation>値</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="580"/>
        <source>Variable value</source>
        <translation>変数の値</translation>
    </message>
</context>
<context>
    <name>FieldSelect</name>
    <message>
        <location filename="../fieldsel.cpp" line="34"/>
        <source>Select Custom Fields </source>
        <translation>カスタム・フィールドの選択 </translation>
    </message>
    <message>
        <location filename="../fieldsel.cpp" line="75"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
</context>
<context>
    <name>Files</name>
    <message>
        <location filename="../details.cpp" line="495"/>
        <source>Fd</source>
        <translation>FD</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="495"/>
        <source>File descriptor</source>
        <translation>ファイル 記述子</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="497"/>
        <source>Mode</source>
        <translation>Mode</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="497"/>
        <source>Open mode</source>
        <translation>オープン モード</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="499"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="499"/>
        <source>File name (if available)</source>
        <translation>ファイル名 (取得可能の場合)</translation>
    </message>
</context>
<context>
    <name>IO_Graph</name>
    <message>
        <location filename="../infobar.cpp" line="785"/>
        <source>I/O Summary:</source>
        <translation>I/O の概要:</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="819"/>
        <source>No input or output</source>
        <translation>入出力無し</translation>
    </message>
</context>
<context>
    <name>IntervalDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="43"/>
        <source>Change Update Period</source>
        <translation>更新間隔の変更</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="49"/>
        <source>New Update Period</source>
        <translation>新しい更新間隔</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="85"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="87"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="121"/>
        <source>No UPDATE</source>
        <translation>値を入れて下さい</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="139"/>
        <source>Invalid value</source>
        <translation>無効な値です</translation>
    </message>
</context>
<context>
    <name>Maps</name>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Address Range</source>
        <translation>アドレス範囲</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="392"/>
        <source>Mapped addresses (hex) )</source>
        <translation>マップされたアドレス (16進数) )</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Size</source>
        <translation>サイズ</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="393"/>
        <source>Kbytes mapped (dec)</source>
        <translation>マップされたキロバイト数 (10 進数)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Perm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="394"/>
        <source>Permission flags</source>
        <translation>パーミッションフラグ</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>Offset</source>
        <translation>オフセット</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="395"/>
        <source>File offset at start of mapping (hex)</source>
        <translation>マッピング開始時のファイルオフセット (16進数)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Device</source>
        <translation>デバイス</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="396"/>
        <source>Major,Minor device numbers (dec)</source>
        <translation>メジャー、マイナーデバイス番号 (10 進数)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="397"/>
        <source>Inode number (dec)</source>
        <translation type="unfinished">Iode番号（dec）</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File</source>
        <translation>ファイル</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="398"/>
        <source>File name (if available)</source>
        <translation>ファイル名 (取得可能の場合)</translation>
    </message>
</context>
<context>
    <name>PermissionDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="264"/>
        <source>Permission</source>
        <translation>パーミッション</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="273"/>
        <source>Root password</source>
        <translation>Root のパスワード</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="280"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="283"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Preferences</name>
    <message>
        <location filename="../prefs.cpp" line="150"/>
        <source>Preferences</source>
        <translation>環境設定</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="157"/>
        <source>Setting</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="191"/>
        <source>%CPU divided by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="198"/>
        <source>Total cpu: %1</source>
        <translation>合計CPU: %1</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="199"/>
        <source>Single cpu: 1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="205"/>
        <source>default</source>
        <translation>既定</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="206"/>
        <source>for developer</source>
        <translation>開発者用</translation>
    </message>
    <message>
        <location filename="../prefs.cpp" line="240"/>
        <source>Appearance</source>
        <translation>外観</translation>
    </message>
</context>
<context>
    <name>Proc</name>
    <message>
        <location filename="../proc.cpp" line="2615"/>
        <source>PID</source>
        <translation>PID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2615"/>
        <source>Process ID</source>
        <translation>プロセス ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2617"/>
        <source>TGID</source>
        <translation>TGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2617"/>
        <source>Task group ID ( parent of threads )</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2619"/>
        <source>PPID</source>
        <translation>PPID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2619"/>
        <source>Parent process ID</source>
        <translation>親プロセス ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2621"/>
        <source>PGID</source>
        <translation>PGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2621"/>
        <source>Process group ID</source>
        <translation>プロセス グループ ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2623"/>
        <source>SID</source>
        <translation>SID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2623"/>
        <source>Session ID</source>
        <translation>セッション ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2625"/>
        <source>TTY</source>
        <translation>TTY</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2625"/>
        <source>Terminal</source>
        <translation>ターミナル</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2627"/>
        <source>TPGID</source>
        <translation>TPGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2627"/>
        <source>Process group ID of tty owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2629"/>
        <source>USER</source>
        <translation>USER</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2629"/>
        <source>Owner (*=suid root, +=suid a user)</source>
        <translation>所有者 (*=suid root, +=suid a user)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2631"/>
        <source>GROUP</source>
        <translation>GROUP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2631"/>
        <source>Group name (*=sgid other)</source>
        <translation>グループ名 (*=sgid other)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2633"/>
        <source>UID</source>
        <translation>UID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2633"/>
        <source>Real user ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2635"/>
        <source>EUID</source>
        <translation>EUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2635"/>
        <source>Effective user ID</source>
        <translation>有効なユーザー ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2637"/>
        <source>SUID</source>
        <translation>SUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2637"/>
        <source>Saved user ID (Posix)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2639"/>
        <source>FSUID</source>
        <translation>FSUID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2639"/>
        <source>File system user ID</source>
        <translation>ファイルシステムのユーザー ID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2641"/>
        <source>GID</source>
        <translation>GID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2641"/>
        <source>Real group ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2643"/>
        <source>EGID</source>
        <translation>EGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2643"/>
        <source>Effective group ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2645"/>
        <source>SGID</source>
        <translation>SGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2645"/>
        <source>Saved group ID (Posix)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2647"/>
        <source>FSGID</source>
        <translation>FSGID</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2647"/>
        <source>File system group ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2649"/>
        <source>PRI</source>
        <translation>PRI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2649"/>
        <source>Dynamic priority</source>
        <translation>動的優先順位</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2651"/>
        <source>NICE</source>
        <translation>NICE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2651"/>
        <source>Scheduling favour (higher -&gt; less cpu time)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2653"/>
        <source>NLWP</source>
        <translation>NLWP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2653"/>
        <source>Number of tasks(threads) in task group</source>
        <translation>タスクグループ内のタスク数 (スレッド数)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2655"/>
        <source>PLCY</source>
        <translation>PLCY</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2655"/>
        <source>Scheduling policy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2657"/>
        <source>RPRI</source>
        <translation>RPRI</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2657"/>
        <source>Realtime priority (0-99, more is better)</source>
        <translation>リアルタイム優先度 (0～99、多いほど良い)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2659"/>
        <source>TMS</source>
        <translation>TMS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2659"/>
        <source>Time slice in milliseconds</source>
        <translation>ミリ秒単位の時間分割</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2661"/>
        <source>%SAVG</source>
        <translation>%SAVG</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2661"/>
        <source>Percentage average sleep time (-1 -&gt; N/A)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2663"/>
        <source>CPUSET</source>
        <translation>CPUSET</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2663"/>
        <source>Affinity CPU mask (0 -&gt; API not supported)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2665"/>
        <source>MAJFLT</source>
        <translation>MAJFLT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2665"/>
        <source>Number of major faults (disk access)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2667"/>
        <source>MINFLT</source>
        <translation>MINFLT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2667"/>
        <source>Number of minor faults (no disk access)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2670"/>
        <source>VSIZE</source>
        <translation>VSIZE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2670"/>
        <source>Virtual image size of process</source>
        <translation>プロセスの仮想イメージサイズ</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2672"/>
        <source>RSS</source>
        <translation>RSS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2672"/>
        <source>Resident set size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2674"/>
        <source>MEM</source>
        <translation>MEM</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2674"/>
        <source>memory usage (RSS-SHARE)</source>
        <translation>メモリ使用量 (RSS-SHARE)</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2676"/>
        <source>TRS</source>
        <translation>TRS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2676"/>
        <source>Text(code) resident set size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2678"/>
        <source>DRS</source>
        <translation>DRS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2678"/>
        <source>Data resident set size(malloc+global variable)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2680"/>
        <source>STACK</source>
        <translation>STACK</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2680"/>
        <source>Stack size</source>
        <translation>スタックサイズ</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2682"/>
        <source>SHARE</source>
        <translation>SHARE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2682"/>
        <source>Shared memory with other libs</source>
        <translation>他のライブラリとの共有メモリ</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2684"/>
        <source>SWAP</source>
        <translation>SWAP</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2684"/>
        <source>Kbytes on swap device</source>
        <translation>スワップデバイスのキロバイト</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2686"/>
        <source>IO_R</source>
        <translation>IO_R</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2686"/>
        <source>io read (file)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2688"/>
        <source>IO_W</source>
        <translation>IO_W</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2688"/>
        <source>io write (file)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2690"/>
        <source>DT</source>
        <translation>DT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2690"/>
        <source>Number of dirty (non-written) pages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2692"/>
        <source>STAT</source>
        <translation>STAT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2692"/>
        <source>State of the process </source>
        <translation>プロセスの状態 </translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2694"/>
        <source>FLAGS</source>
        <translation>FLAGS</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2694"/>
        <source>Process flags (hex)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2696"/>
        <source>WCHAN</source>
        <translation>WCHAN</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2696"/>
        <source>Kernel function where process is sleeping</source>
        <translation>プロセスがスリープしているカーネル関数</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2698"/>
        <source>%WCPU</source>
        <translation>%WCPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2698"/>
        <source>Weighted percentage of CPU (30 s average)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2700"/>
        <source>%CPU</source>
        <translation>%CPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2700"/>
        <source>Percentage of CPU used since last update</source>
        <translation>前回更新時からの CPU 使用率</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2702"/>
        <source>%MEM</source>
        <translation>%MEM</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2702"/>
        <source>Percentage of memory used (RSS/total mem)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2704"/>
        <source>START</source>
        <translation>START</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2704"/>
        <source>Time process started</source>
        <translation>プロセス開始時刻</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2706"/>
        <source>TIME</source>
        <translation>TIME</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2706"/>
        <source>Total CPU time used since start</source>
        <translation>起動時からの CPU 使用時間の合計</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2708"/>
        <source>CPU</source>
        <translation>CPU</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2708"/>
        <source>CPU the process is executing on (SMP system)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2710"/>
        <source>the process name</source>
        <translation>プロセスの名前</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2710"/>
        <source>Process Name</source>
        <translation>Process Name</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2714"/>
        <source>CWD</source>
        <translation>CWD</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2714"/>
        <source>Current working directory</source>
        <translation>現在の作業ディレクトリ</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2715"/>
        <source>ROOT</source>
        <translation>ROOT</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2715"/>
        <source>Root directory of process</source>
        <translation>プロセスのルートディレクトリ</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2718"/>
        <source>COMMAND_LINE</source>
        <translation>COMMAND_LINE</translation>
    </message>
    <message>
        <location filename="../proc.cpp" line="2718"/>
        <source>Command line that started the process</source>
        <translation>プロセスを開始したコマンドライン</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../qps.cpp" line="1618"/>
        <source>Show</source>
        <translation>表示</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1621"/>
        <source>Hide</source>
        <translation>非表示</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1626"/>
        <source>Quit</source>
        <translation>終了</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="430"/>
        <location filename="../infobar.cpp" line="437"/>
        <source>User: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="431"/>
        <location filename="../infobar.cpp" line="438"/>
        <source>System: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="432"/>
        <location filename="../infobar.cpp" line="439"/>
        <source>Nice: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="430"/>
        <location filename="../infobar.cpp" line="431"/>
        <location filename="../infobar.cpp" line="432"/>
        <location filename="../infobar.cpp" line="437"/>
        <location filename="../infobar.cpp" line="438"/>
        <location filename="../infobar.cpp" line="439"/>
        <source>%</source>
        <translation type="unfinished">%</translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="474"/>
        <location filename="../infobar.cpp" line="509"/>
        <source>Total: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="477"/>
        <location filename="../infobar.cpp" line="515"/>
        <source>Used: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="481"/>
        <source>Cached: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="484"/>
        <source>Buffer: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="512"/>
        <source>Free: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="554"/>
        <source>Time passed after system boot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="582"/>
        <source>Average CPU load each 1, 5 ,15 minutes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../infobar.cpp" line="727"/>
        <source>CPU Usage Summary:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Qps</name>
    <message>
        <location filename="../qps.cpp" line="171"/>
        <source>header_popup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="172"/>
        <source>Remove Field</source>
        <translation>フィールドの削除</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="173"/>
        <source>Add Field</source>
        <translation>フィールドの追加</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="176"/>
        <source>Session</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="180"/>
        <source>View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="181"/>
        <source>Process</source>
        <translation>プロセス</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="182"/>
        <source>Log</source>
        <translation>ログ</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="187"/>
        <source>Fields</source>
        <translation>フィールド</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="188"/>
        <source>Custom Fields</source>
        <translation>カスタム・フィールド</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="190"/>
        <source>Basic Fields </source>
        <translation>ベーシック・フィールド </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="192"/>
        <source>Jobs Fields </source>
        <translation>ジョブ・フィールド </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="194"/>
        <source>Memory Fields </source>
        <translation>メモリ・フィールド </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="197"/>
        <source>Scheduling Fields </source>
        <translation>スケジュール・フィールド </translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="214"/>
        <source>Select Custom Fields...</source>
        <translation>カスタム・フィールドの選択...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="223"/>
        <source>Options</source>
        <translation>オプション</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="224"/>
        <source>Update Period...</source>
        <translation>更新間隔...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="233"/>
        <source>Show Status bar</source>
        <translation>ステータスバーの表示</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="242"/>
        <source>Preferences...</source>
        <translation>設定...</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="248"/>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="249"/>
        <location filename="../qps.cpp" line="1666"/>
        <source>About</source>
        <translation>このアプリケーションについて</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="335"/>
        <source>test</source>
        <translation>テスト</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="336"/>
        <source>Copied to Clipboard</source>
        <translation>クリップボードにコピーしました</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="388"/>
        <source>context popup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="389"/>
        <source>Renice...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="390"/>
        <source>Scheduling...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="392"/>
        <source>Terminate</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="393"/>
        <source>Hangup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="394"/>
        <source>Kill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="395"/>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="397"/>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="400"/>
        <source>Other Signals</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="401"/>
        <source>SIGINT (interrupt)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="403"/>
        <source>SIGCONT (continue)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="405"/>
        <source>SIGSTOP (stop)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="407"/>
        <source>SIGQUIT (quit)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="409"/>
        <source>SIGILL (illegal instruction)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="411"/>
        <source>SIGABRT (abort)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="413"/>
        <source>SIGFPE (floating point exception)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="415"/>
        <source>SIGSEGV (segmentation violation)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="417"/>
        <source>SIGPIPE (broken pipe)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="419"/>
        <source>SIGALRM (timer signal)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="421"/>
        <source>SIGUSR1 (user-defined 1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="423"/>
        <source>SIGUSR2 (user-defined 2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="425"/>
        <source>SIGCHLD (child death)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="427"/>
        <source>SIGTSTP (stop from tty)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="429"/>
        <source>SIGTTIN (tty input)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="431"/>
        <source>SIGTTOU (tty output)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="438"/>
        <source>View Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="676"/>
        <source>Show File Path</source>
        <translation>ファイルのパスを表示</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="682"/>
        <source>Show Graph</source>
        <translation>グラフの表示</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="688"/>
        <source>Show Control Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="699"/>
        <source>Include Child Times</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="287"/>
        <source>Quit</source>
        <translation>終了</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1144"/>
        <location filename="../qps.cpp" line="1175"/>
        <location filename="../qps.cpp" line="1182"/>
        <location filename="../qps.cpp" line="1203"/>
        <location filename="../qps.cpp" line="1237"/>
        <location filename="../qps.cpp" line="1332"/>
        <source>Permission denied</source>
        <translation>アクセスが拒否されました</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1145"/>
        <source>You do not have permission to renice the selected processes. Only the process owner and the super-user are allowed to do that.</source>
        <translation>選択したプロセスの優先度を変更する権限がありません。プロセスの所有者とスーパー・ユーザーのみが許可されています。</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1176"/>
        <source>You do not have permission to renice process %1 (%2).Only the process owner and the super-user are allowed to do that.</source>
        <translation>プロセス %1 (%2) の優先順位を変更する権限がありません。プロセスの所有者とスーパー・ユーザーのみが許可されています。</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1183"/>
        <source>Only the super-user may lower the nice value of a process.</source>
        <translation>スーパー・ユーザーだけが、プロセスの nice 値を下げることができます。</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1204"/>
        <source>Only the super-user may change the scheduling policy and static priority.</source>
        <translation>スーパー・ユーザーだけが、スケジューリング・ポリシーと静的優先度を変更することできます。</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1238"/>
        <source>You do not have permission to change the scheduling and/or priority of process %1 (%2). Only the super-user may do that.</source>
        <translation>プロセス %1 (%2) の優先順位とスケジュールの両方またはいずれかを変更するアクセス許可がありません。スーパーユーザーだけはそれを行うことができます。</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1299"/>
        <source>Do you really want to terminate the selected process(es)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1301"/>
        <source>Do you really want to hang up the selected process(es)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1303"/>
        <source>Do you really want to kill the selected process(es)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1312"/>
        <source>Question</source>
        <translation>質問</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1333"/>
        <source>You do not have permission to send a signal to process %1 (%2). Only the super-user and the owner of the process may send signals to it.</source>
        <translation>プロセス %1 (%2) に信号を送信するアクセス許可がありません。プロセスの所有者とスーパーユーザーのみが信号を送信できます。</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1682"/>
        <source>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</source>
        <translation>&lt;center&gt;&lt;h2&gt; Qps %1&lt;/center&gt;</translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1684"/>
        <source>&lt;h2&gt; Qps %1 - A Visual Process Manager &lt;/h2&gt; %2 using Qt library %3&lt;br&gt;&lt;br&gt;&lt;b&gt;Source: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps&quot;&gt;https://github.com/lxqt/qps/&lt;/a&gt;&lt;br&gt;&lt;b&gt;Bugtracker: &lt;/b&gt;&lt;a href=&quot;https://github.com/lxqt/qps/issues&quot;&gt;https://github.com/lxqt/qps/issues&lt;/a&gt;&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qps.cpp" line="1704"/>
        <source>&lt;b&gt;Original Qps by&lt;/b&gt;&lt;br&gt;Mattias Engdegård (f91-men@nada.kth.se)&lt;br&gt;&lt;br&gt;&lt;b&gt;Contributors&lt;/b&gt;&lt;br&gt;Olivier.Daudel@u-paris10.fr&lt;br&gt;jsanchez@todounix.homeip.net &lt;br&gt;daehyun.yang@gmail.com &lt;br&gt;Luís Pereira (luis.artur.pereira@gmail.com)&lt;br&gt;Alf Gaida (agaida@siduction.org)&lt;br&gt;Paulo Lieuthier (paulolieuthier@gmail.com)&lt;br&gt;Jerome Leclanche (jerome@leclan.ch)&lt;br&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SchedDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="292"/>
        <source>Change scheduling</source>
        <translation>スケジューリングの変更</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="296"/>
        <source>Scheduling Policy</source>
        <translation>スケジューリングの方針</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="298"/>
        <source>SCHED_OTHER (time-sharing)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="299"/>
        <source>SCHED_FIFO (real-time)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="300"/>
        <source>SCHED_RR (real-time)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="314"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="316"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="346"/>
        <source>Priority (1-99):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="379"/>
        <source>Invalid Input</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="380"/>
        <source>The priority must be in the range 1..99</source>
        <translation>優先順位は 1..99 の範囲である必要があります</translation>
    </message>
</context>
<context>
    <name>SearchBox</name>
    <message>
        <location filename="../misc.cpp" line="588"/>
        <source>PID, COMMAND, USER...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../misc.cpp" line="589"/>
        <source>Filter</source>
        <translation>フィルター</translation>
    </message>
</context>
<context>
    <name>SliderDialog</name>
    <message>
        <location filename="../dialogs.cpp" line="179"/>
        <source>Renice Process</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="185"/>
        <source>New nice value:</source>
        <translation>新しい nice 値:</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="225"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../dialogs.cpp" line="229"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>Sockets</name>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>Fd</source>
        <translation type="unfinished">FD</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="147"/>
        <source>File descriptor</source>
        <translation type="unfinished">ファイル 記述子</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Proto</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../details.cpp" line="148"/>
        <source>Protocol (TCP or UDP)</source>
        <translation>プロトコル (TCP または UDP)</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Recv-Q</source>
        <translation>Recv-Q</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="149"/>
        <source>Bytes in receive queue</source>
        <translation>受信キューのバイト数</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Send-Q</source>
        <translation type="unfinished">Send-Q</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="150"/>
        <source>Bytes in send queue</source>
        <translation>送信キューのバイト数</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local Addr</source>
        <translation>ローカル アド</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="151"/>
        <source>Local IP address</source>
        <translation>ローカル IP アドレス</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <location filename="../details.cpp" line="154"/>
        <source>Port</source>
        <translation>ポート</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="152"/>
        <source>Local port</source>
        <translation>ローカル ポート</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote Addr</source>
        <translation>リモート アド</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="153"/>
        <source>Remote IP address</source>
        <translation>リモート IP アドレス</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="154"/>
        <source>Remote port</source>
        <translation>リモート ポート</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>State</source>
        <translation>状態</translation>
    </message>
    <message>
        <location filename="../details.cpp" line="155"/>
        <source>Connection state</source>
        <translation>接続の状態</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <location filename="../misc.cpp" line="624"/>
        <source>Process count: %1</source>
        <translation>プロセス数: %1</translation>
    </message>
</context>
<context>
    <name>TBloon</name>
    <message>
        <location filename="../misc.cpp" line="343"/>
        <source> This is unstable Alpha feature
 You maybe see a SEGFAULT...</source>
        <translation> これは不安定なアルファの機能です
 SEGFAULT を参照して下さい...</translation>
    </message>
</context>
<context>
    <name>UFrame</name>
    <message>
        <location filename="../misc.cpp" line="485"/>
        <source>title</source>
        <translation>タイトル</translation>
    </message>
</context>
</TS>
